@@ -1,6 +1,6 @@
 # coding=utf-8
 # pynput
-# Copyright (C) 2015-2021 Moses Palmér
+# Copyright (C) 2015-2022 Moses Palmér
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -42,7 +42,7 @@ def _wrap_value(value):
 
     :return: a wrapped value
     """
-    return objc.objc_object(c_void_p=value)
+    return objc.objc_object(c_void_p=value) if value is not None else None
 
 
 @contextlib.contextmanager
